@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 
@@ -144,6 +144,8 @@ static QString fix_foldername(QString ofolder) {
 		while ((folder.length()>1) && (folder.right(1) == "/"))
 			folder = folder.left(folder.length()-1);
 	}
+	if (folder.length() == 0)
+		folder = "/";
 	return folder;
 }
 
@@ -205,6 +207,8 @@ void KameraProtocol::get(const KURL &url)
 		gp_file_free(m_file);
 		if ((gpr == GP_ERROR_FILE_NOT_FOUND) || (gpr == GP_ERROR_DIRECTORY_NOT_FOUND))
 			error(KIO::ERR_DOES_NOT_EXIST, url.path());
+		else
+			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 		closeCamera();
 		return;
 	}
@@ -290,13 +294,22 @@ void KameraProtocol::get(const KURL &url)
 // The KIO slave "stat" function.
 void KameraProtocol::stat(const KURL &url)
 {
-	kdDebug(7123) << "KameraProtocol("<<this<<")::stat(" << url.path() << ")" << endl;
+	kdDebug(7123) << "stat(\"" << url.path() << "\")" << endl;
+	
+	if (url.path() == "") {
+		KURL rooturl(url);
 
-	if(url.path() == "/") {
-		statRoot();
-	} else {
-		statRegular(url);
+		kdDebug(7123) << "redirecting to /" << endl;
+		rooturl.setPath("/");
+		redirection(rooturl);
+		finished();
+		return;
 	}
+
+	if(url.path() == "/")
+		statRoot();
+	else
+		statRegular(url);
 }
 
 // Implements stat("/") -- which always returns the same value.
@@ -340,10 +353,13 @@ void KameraProtocol::statRegular(const KURL &url)
 	CameraList *dirList;
 	gp_list_new(&dirList);
 	kdDebug(7123) << "statRegular() Requesting directories list for " << url.directory() << endl;
+
 	gpr = gp_camera_folder_list_folders(m_camera, tocstr(fix_foldername(url.directory(false))), dirList, m_context);
 	if (gpr != GP_OK) {
 		if ((gpr == GP_ERROR_FILE_NOT_FOUND) || (gpr == GP_ERROR_DIRECTORY_NOT_FOUND))
 			error(KIO::ERR_DOES_NOT_EXIST, url.path());
+		else
+			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 		gp_list_free(dirList);
 		closeCamera();
 		return;
@@ -389,6 +405,8 @@ void KameraProtocol::statRegular(const KURL &url)
 	if (gpr != GP_OK) {
 		if ((gpr == GP_ERROR_FILE_NOT_FOUND) || (gpr == GP_ERROR_DIRECTORY_NOT_FOUND))
 			error(KIO::ERR_DOES_NOT_EXIST, url.path());
+		else
+			error(KIO::ERR_UNKNOWN, gp_result_as_string(gpr));
 		closeCamera();
 		return;
 	}
@@ -454,25 +472,26 @@ void KameraProtocol::listDir(const KURL &url)
 		/* Autodetect USB cameras ... */
 		GPContext *glob_context = NULL;
 		int i, count;
-		CameraList list;
+		CameraList *list;
 		CameraAbilitiesList *al;
 		GPPortInfoList *il;
 
+		gp_list_new (&list);
 		gp_abilities_list_new (&al);
 		gp_abilities_list_load (al, glob_context);
 		gp_port_info_list_new (&il);
 		gp_port_info_list_load (il);
-		gp_abilities_list_detect (al, il, &list, glob_context);
+		gp_abilities_list_detect (al, il, list, glob_context);
 		gp_abilities_list_free (al);
 		gp_port_info_list_free (il);
 
-		count = gp_list_count (&list);
+		count = gp_list_count (list);
 
 		for (i = 0 ; i<count ; i++) {
 			const char *model, *value;
 
-			gp_list_get_name  (&list, i, &model);
-			gp_list_get_value (&list, i, &value);
+			gp_list_get_name  (list, i, &model);
+			gp_list_get_value (list, i, &value);
 	
 			ports[value] = model;
 			// NOTE: We might get different ports than usb: later!
@@ -487,6 +506,7 @@ void KameraProtocol::listDir(const KURL &url)
 			m_config->writeEntry("Path",value);
 			modelcnt[model]++;
 		}
+		gp_list_free (list);
 
 		/* Avoid duplicated entry for usb: and usb:001,042 entries. */
 		if (ports.contains("usb:") && names[ports["usb:"]]!="usb:")
@@ -679,6 +699,10 @@ void KameraProtocol::setHost(const QString& host, int port, const QString& user,
 		gp_port_info_list_new(&port_info_list);
 		gp_port_info_list_load(port_info_list);
 		idx = gp_port_info_list_lookup_path(port_info_list, tocstr(host));
+
+		/* Handle erronously passed usb:XXX,YYY */
+		if ((idx < 0) && host.startsWith("usb:"))
+			idx = gp_port_info_list_lookup_path(port_info_list, "usb:");
 		if (idx < 0) {
 			gp_port_info_list_free(port_info_list);
 			kdDebug(7123) << "Unable to get port info for path: " << host << endl;
