@@ -3,10 +3,11 @@
 // (C) 2001-2003 Stefan Kebekus
 // Distributed under the GPL
 
+#include <config.h>
+
 #include <kdebug.h>
 #include <kio/global.h>
 #include <klocale.h>
-#include <kpushbutton.h>
 #include <qfile.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -85,8 +86,9 @@ void infoDialog::setFontInfo(fontPool *fp)
   TextLabel2->setText(fp->status());
 }
 
-void infoDialog::outputReceiver(QString op)
+void infoDialog::outputReceiver(const QString& _op)
 {
+  QString op = _op;
   op = op.replace( QRegExp("<"), "&lt;" );
 
   if (MFOutputReceived == false) {
@@ -123,7 +125,7 @@ void infoDialog::outputReceiver(QString op)
   MFOutputReceived = true;
 }
 
-void infoDialog::clear(QString op)
+void infoDialog::clear(const QString& op)
 {
   headline         = op;
   pool             = QString::null;
