@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */  
 
 #ifndef __KICONEDITGRID_H__
@@ -25,7 +25,9 @@
 #include <qimage.h>
 #include <qcursor.h>
 #include <qpointarray.h>
+#include <qframe.h>
 #include <kcommand.h>
+#include <klocale.h>
 
 #include "kcolorgrid.h"
 
@@ -155,6 +157,30 @@ public:
   	setColor( colNum, v, update );
   };
 
+  enum TransparencyDisplayType
+  {
+    TRD_SOLIDCOLOR,
+    TRD_CHECKERBOARD
+  };
+  enum CheckerboardSize
+  {
+    CHK_SMALL = 0,
+    CHK_MEDIUM = 1,
+    CHK_LARGE = 2
+  };
+
+  TransparencyDisplayType transparencyDisplayType() const { return m_transparencyDisplayType; }
+  QColor checkerboardColor1() const { return m_checkerboardColor1; }
+  QColor checkerboardColor2() const { return m_checkerboardColor2; }
+  CheckerboardSize checkerboardSize() const { return m_checkerboardSize; }
+  QColor transparencySolidColor() const { return m_transparencySolidColor; }
+
+  void setTransparencyDisplayType(TransparencyDisplayType t) { m_transparencyDisplayType = t; }
+  void setCheckerboardColor1(const QColor& c) { m_checkerboardColor1 = c; }
+  void setCheckerboardColor2(const QColor& c) { m_checkerboardColor2 = c; }
+  void setCheckerboardSize(CheckerboardSize size) { m_checkerboardSize = size; }
+  void setTransparencySolidColor(const QColor& c) { m_transparencySolidColor = c; }
+
 public slots:
   void load( QImage *);
   void editCopy(bool cut = false);
@@ -187,6 +213,7 @@ signals:
   void selecteddata(bool);
   void needPainting();
   void modifiedchanged(bool);
+  void colorSelected(uint);
 
 protected slots:
   void setColorSelection( uint );
@@ -194,7 +221,7 @@ protected slots:
 
 protected:
   virtual void paintEvent(QPaintEvent*);
-  virtual void paintCell( QPainter*, int, int );
+  virtual void paintCell( QPainter*, int, int ) {}
   virtual void paintForeground(QPainter* p, QPaintEvent* e);
   virtual void mousePressEvent(QMouseEvent*);
   virtual void mouseReleaseEvent(QMouseEvent*);
@@ -221,6 +248,11 @@ protected:
   KCommandHistory* history;
   KMacroCommand* m_command;
   QCursor cursor_normal, cursor_aim, cursor_flood, cursor_spray, cursor_erase, cursor_paint, cursor_colorpicker;
+  TransparencyDisplayType m_transparencyDisplayType;
+  QColor m_checkerboardColor1;
+  QColor m_checkerboardColor2;
+  CheckerboardSize m_checkerboardSize;
+  QColor m_transparencySolidColor;
 };
 
 
