@@ -71,6 +71,7 @@
 #define kpSettingShowPath QString::fromLatin1 ("Show Path")
 #define kpSettingColorSimilarity QString::fromLatin1 ("Color Similarity")
 #define kpSettingDitherOnOpen QString::fromLatin1 ("Dither on Open if Screen is 15/16bpp and Image Num Colors More Than")
+#define kpSettingPrintImageCenteredOnPage QString::fromLatin1 ("Print Image Centered On Page")
 
 #define kpSettingsGroupFileSaveAs QString::fromLatin1 ("File/Save As")
 #define kpSettingsGroupFileExport QString::fromLatin1 ("File/Export")
@@ -114,6 +115,7 @@
 
 #define kpSettingsGroupTools QString::fromLatin1 ("Tool Settings")
 #define kpSettingLastTool QString::fromLatin1 ("Last Used Tool")
+#define kpSettingToolBoxIconSize QString::fromLatin1 ("Tool Box Icon Size")
 
 
 #define kpSettingsGroupText QString::fromLatin1 ("Text Settings")
