@@ -24,7 +24,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: ksaneocr.cpp 370359 2004-12-13 14:01:48Z freitag $ */
+/* $Id: ksaneocr.cpp 470596 2005-10-14 12:59:58Z mueller $ */
 
 #include <kdebug.h>
 #include <kmessagebox.h>
@@ -104,11 +104,14 @@ KSANEOCR::KSANEOCR( QWidget*, KConfig *cfg ):
         konf->setGroup( CFG_GROUP_OCR_DIA );
         QString eng = konf->readEntry(CFG_OCR_ENGINE, "ocrad");
 
-	if( eng == "ocrad" )
-	{
-	    m_ocrEngine = OCRAD;
-	}
-
+        if( eng == "ocrad" )
+        {
+            m_ocrEngine = OCRAD;
+        }
+        else if( eng == "gocr" )
+        {
+            m_ocrEngine = GOCR;
+        }
 #ifdef HAVE_KADMOS
         else if( eng == QString("kadmos") ) m_ocrEngine = KADMOS;
 #endif
@@ -1198,7 +1201,7 @@ bool KSANEOCR::eventFilter( QObject *object, QEvent *event )
         }
     }
     return false;
-};
+}
 
 
 
