@@ -12,7 +12,7 @@
  *   Copyright (C) 2004 by Christoph Cullmann <crossfire@babylon2k.de>     *
  *   Copyright (C) 2004 by Henrique Pinto <stampede@coltec.ufmg.br>        *
  *   Copyright (C) 2004 by Waldo Bastian <bastian@kde.org>                 *
- *   Copyright (C) 2004 by Albert Astals Cid <tsdgeos@terra.es>            *
+ *   Copyright (C) 2004-2006 by Albert Astals Cid <tsdgeos@terra.es>       *
  *   Copyright (C) 2004 by Antti Markus <antti.markus@starman.ee>          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -149,9 +149,9 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 
 	int index;
 	// [left toolbox: Table of Contents] | []
-	TOC * tocFrame = new TOC( m_toolBox, m_document );
-	connect(tocFrame, SIGNAL(hasTOC(bool)), this, SLOT(enableTOC(bool)));
-	index = m_toolBox->addItem( tocFrame, QIconSet(SmallIcon("text_left")), i18n("Contents") );
+	m_tocFrame = new TOC( m_toolBox, m_document );
+	connect(m_tocFrame, SIGNAL(hasTOC(bool)), this, SLOT(enableTOC(bool)));
+	index = m_toolBox->addItem( m_tocFrame, QIconSet(SmallIcon("text_left")), i18n("Contents") );
 	m_toolBox->setItemToolTip(index, i18n("Contents"));
 	enableTOC( false );
 
@@ -186,8 +186,8 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	miniSpacer->setFixedHeight( 6 );
 	miniBarLayout->addWidget( miniSpacer );
 	// widgets: [../[../MiniBar]] | []
-	MiniBar * miniBar = new MiniBar( miniBarContainer, m_document );
-	miniBarLayout->addWidget( miniBar );
+	m_miniBar = new MiniBar( miniBarContainer, m_document );
+	miniBarLayout->addWidget( m_miniBar );
 
 	// widgets: [] | [right 'pageView']
 	m_pageView = new PageView( m_splitter, m_document );
@@ -199,8 +199,8 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_document->addObserver( this );
 	m_document->addObserver( m_thumbnailList );
 	m_document->addObserver( m_pageView );
-	m_document->addObserver( tocFrame );
-	m_document->addObserver( miniBar );
+	m_document->addObserver( m_tocFrame );
+	m_document->addObserver( m_miniBar );
 
 	// ACTIONS
 	KActionCollection * ac = actionCollection();
@@ -209,19 +209,19 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_gotoPage = KStdAction::gotoPage( this, SLOT( slotGoToPage() ), ac, "goto_page" );
 	m_gotoPage->setShortcut( "CTRL+G" );
 	// dirty way to activate gotopage when pressing miniBar's button
-	connect( miniBar, SIGNAL( gotoPage() ), m_gotoPage, SLOT( activate() ) );
+	connect( m_miniBar, SIGNAL( gotoPage() ), m_gotoPage, SLOT( activate() ) );
 
 	m_prevPage = KStdAction::prior(this, SLOT(slotPreviousPage()), ac, "previous_page");
 	m_prevPage->setWhatsThis( i18n( "Moves to the previous page of the document" ) );
 	m_prevPage->setShortcut( "Backspace" );
 	// dirty way to activate prev page when pressing miniBar's button
-	connect( miniBar, SIGNAL( prevPage() ), m_prevPage, SLOT( activate() ) );
+	connect( m_miniBar, SIGNAL( prevPage() ), m_prevPage, SLOT( activate() ) );
 
 	m_nextPage = KStdAction::next(this, SLOT(slotNextPage()), ac, "next_page" );
 	m_nextPage->setWhatsThis( i18n( "Moves to the next page of the document" ) );
 	m_nextPage->setShortcut( "Space" );
 	// dirty way to activate next page when pressing miniBar's button
-	connect( miniBar, SIGNAL( nextPage() ), m_nextPage, SLOT( activate() ) );
+	connect( m_miniBar, SIGNAL( nextPage() ), m_nextPage, SLOT( activate() ) );
 
 	m_firstPage = KStdAction::firstPage( this, SLOT( slotGotoFirst() ), ac, "first_page" );
 	m_firstPage->setWhatsThis( i18n( "Moves to the first page of the document" ) );
@@ -291,6 +291,11 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 
 Part::~Part()
 {
+    delete m_tocFrame;
+    delete m_pageView;
+    delete m_thumbnailList;
+    delete m_miniBar;
+
     delete m_document;
     if ( --m_count == 0 )
         delete globalParams;
@@ -697,6 +702,11 @@ void Part::slotSaveFileAs()
     KURL saveURL = KFileDialog::getSaveURL( url().isLocalFile() ? url().url() : url().fileName(), QString::null, widget() );
     if ( saveURL.isValid() && !saveURL.isEmpty() )
     {
+        if (saveURL == url())
+        {
+            KMessageBox::information( widget(), i18n("You are trying to overwrite \"%1\" with itself. This is not allowed. Please save it in another location.").arg(saveURL.filename()) );
+            return;
+        }
         if ( KIO::NetAccess::exists( saveURL, false, widget() ) )
         {
             if (KMessageBox::warningContinueCancel( widget(), i18n("A file named \"%1\" already exists. Are you sure you want to overwrite it?").arg(saveURL.filename()), QString::null, i18n("Overwrite")) != KMessageBox::Continue)
