@@ -51,6 +51,7 @@
 #include <kprinter.h>
 #include <kpropertiesdialog.h>
 #include <kstdaccel.h>
+#include <kstdguiitem.h>
 #include <kstandarddirs.h>
 #include <kglobalsettings.h>
 #include <ktempfile.h>
@@ -88,6 +89,8 @@ ImageWindow::~ImageWindow()
 
 void ImageWindow::init()
 {
+    setFocusPolicy( QWidget::StrongFocus );
+    
     KCursor::setAutoHideCursor( this, true, true );
     KCursor::setHideCursorDelay( 1500 );
 
@@ -557,10 +560,6 @@ void ImageWindow::keyPressEvent( QKeyEvent *e )
         close( true );
     else if ( KStdAccel::save().contains( KKey( e ) ) )
         saveImage();
-    else if ( key == Key_Right || key == Key_Down )
-        emit nextSlideRequested();
-    else if ( key == Key_Left || key == Key_Up )
-        emit prevSlideRequested(); // For future use...
 
     else {
         e->ignore();
@@ -626,6 +625,9 @@ void ImageWindow::updateCursor( KuickCursor cursor )
             break;
         case DefaultCursor:
         default:
+            if ( isCursorHidden() )
+                return;
+            
             if ( imageWidth() > width() || imageHeight() > height() )
                 setCursor( *s_handCursor );
             else
@@ -743,10 +745,8 @@ void ImageWindow::mouseReleaseEvent( QMouseEvent *e )
     w = (uint) ( factor * (float) imageWidth() );
     h = (uint) ( factor * (float) imageHeight() );
 
-    if ( w > kdata->maxWidth || h > kdata->maxHeight ) {
-	qDebug("KuickShow: scaling larger than configured maximum -> aborting" );
+    if ( !canZoomTo( w, h ) )
 	return;
-    }
 
     int xtmp = - (int) (factor * abs(xpos - topX) );
     int ytmp = - (int) (factor * abs(ypos - topY) );
@@ -769,8 +769,9 @@ void ImageWindow::mouseReleaseEvent( QMouseEvent *e )
 }
 
 
-void ImageWindow::focusInEvent( QFocusEvent * )
+void ImageWindow::focusInEvent( QFocusEvent *ev )
 {
+    ImlibWidget::focusInEvent( ev );
     emit sigFocusWindow( this );
 }
 
@@ -1119,6 +1120,42 @@ void ImageWindow::maximize()
     kdata->downScale = oldDownscale;
 }
 
+bool ImageWindow::canZoomTo( int newWidth, int newHeight )
+{
+    if ( !ImlibWidget::canZoomTo( newWidth, newHeight ) )
+        return false;
+    
+    QSize desktopSize = KGlobalSettings::desktopGeometry(topLevelWidget()).size();
+
+    int desktopArea = desktopSize.width() * desktopSize.height();
+    int imageArea = newWidth * newHeight;
+    
+    if ( imageArea > desktopArea * kdata->maxZoomFactor )
+    {
+        return KMessageBox::warningContinueCancel(
+            this,
+            i18n("You are about to view a very large image (%1 x %2 pixels), which can be very resource-consuming and even make your computer hang.\nDo you want to continue?")
+            .arg( newWidth ).arg( newHeight ),
+            QString::null,
+            KStdGuiItem::cont(),
+            "ImageWindow_confirm_very_large_window"
+            ) == KMessageBox::Continue;
+    }
+    
+    return true;
+}
+
+void ImageWindow::rotated( KuickImage *kuim, int rotation )
+{
+    if ( !m_kuim )
+        return;
+
+    ImlibWidget::rotated( kuim, rotation );
+    
+    if ( rotation == ROT_90 || rotation == ROT_270 )
+        autoScale( kuim );
+}
+
 void ImageWindow::slotProperties()
 {
     KURL url;
@@ -1126,4 +1163,23 @@ void ImageWindow::slotProperties()
     (void) new KPropertiesDialog( url, this, "props dialog", true );
 }
 
+void ImageWindow::setBusyCursor()
+{
+    // avoid busy cursor in fullscreen mode
+    if ( !isFullscreen() )
+        ImlibWidget::setBusyCursor();
+}
+
+void ImageWindow::restoreCursor()
+{
+    // avoid busy cursor in fullscreen mode
+    if ( !isFullscreen() )
+        ImlibWidget::restoreCursor();
+}
+
+bool ImageWindow::isCursorHidden() const
+{
+    return cursor().shape() == Qt::BlankCursor;
+}
+    
 #include "imagewindow.moc"
