@@ -89,8 +89,6 @@ signals:
   void          requestImage( ImageWindow *, int advance );
   void          deleteImage(ImageWindow *viewer);
   void          trashImage(ImageWindow *viewer);
-  void		nextSlideRequested();
-  void		prevSlideRequested();
 
 protected:
   ~ImageWindow(); // deletes itself, just call close( true );
@@ -100,6 +98,8 @@ protected:
   void          addAlternativeShortcut( KAction *action, int key );
   virtual void	updateGeometry( int imWidth, int imHeight );
   virtual void  loaded( KuickImage * );
+  virtual bool  canZoomTo( int newWidth, int newHeight );
+  virtual void  rotated( KuickImage *kuim, int rotation );
 
   virtual void  wheelEvent( QWheelEvent * );
   virtual void	keyPressEvent( QKeyEvent * );
@@ -144,6 +144,8 @@ protected slots:
   void          reload();
   void          slotProperties();
   void          pauseSlideShow();
+  virtual void  setBusyCursor();
+  virtual void  restoreCursor();
 
 signals:
   void          pauseSlideShowSignal();
@@ -154,6 +156,7 @@ private:
   QSize		maxImageSize() const;
   void          setupActions();
   void 		setPopupMenu();
+  bool          isCursorHidden() const;
 
   bool 		myIsFullscreen;
   int           m_numHeads;
