@@ -231,16 +231,22 @@ void ImlibWidget::zoomImage( float factor )
     if ( factor == 1 || factor == 0 || !m_kuim )
 	return;
 
-    float wf, hf;
+    int newWidth  = (int) (factor * (float) m_kuim->width());
+    int newHeight = (int) (factor * (float) m_kuim->height());
 
-    wf = (float) m_kuim->width() * factor;
-    hf = (float) m_kuim->height() * factor;
+    if ( canZoomTo( newWidth, newHeight ) )
+    {
+        m_kuim->resize( newWidth, newHeight );
+        autoUpdate( true );
+    }
+}
 
-    if ( wf <= 2.0 || hf <= 2.0 ) // minimum size for an image is 2x2 pixels
-	return;
+bool ImlibWidget::canZoomTo( int newWidth, int newHeight )
+{
+    if ( newWidth <= 2 || newHeight <= 2 ) // minimum size for an image is 2x2 pixels
+	return false;
 
-    m_kuim->resize( (int) wf, (int) hf );
-    autoUpdate( true );
+    return true;
 }
 
 
@@ -332,6 +338,7 @@ void ImlibWidget::rotate90()
 	return;
 
     m_kuim->rotate( ROT_90 );
+    rotated( m_kuim, ROT_90 );
     autoUpdate( true );
 }
 
@@ -341,6 +348,7 @@ void ImlibWidget::rotate180()
 	return;
 
     m_kuim->rotate( ROT_180 );
+    rotated( m_kuim, ROT_180 );
     autoUpdate();
 }
 
@@ -350,6 +358,7 @@ void ImlibWidget::rotate270()
 	return;
 
     m_kuim->rotate( ROT_270 );
+    rotated( m_kuim, ROT_270 );
     autoUpdate( true );
 }
 
@@ -464,7 +473,8 @@ void ImlibWidget::setBusyCursor()
 
 void ImlibWidget::restoreCursor()
 {
-    setCursor( m_oldCursor );
+    if ( cursor().shape() == KCursor::waitCursor().shape() ) // only if nobody changed the cursor in the meantime!
+         setCursor( m_oldCursor );
 }
 
 // Reparenting a widget in Qt in fact means destroying the old X window of the widget
@@ -485,6 +495,10 @@ void ImlibWidget::reparent( QWidget* parent, WFlags f, const QPoint& p, bool sho
         XMapWindow( x11Display(), win );
 }
 
+void ImlibWidget::rotated( KuickImage *, int )
+{
+}
+
 //----------
 
 
@@ -807,10 +821,10 @@ ImlibImage * ImageCache::loadImageWithQt( const QString& fileName ) const
     const int NUM_BYTES_NEW  = 3; // 24 bpp
     uchar *newImageData = new uchar[numPixels * NUM_BYTES_NEW];
     uchar *newData = newImageData;
-    
+
     int w = image.width();
     int h = image.height();
-    
+
     for (int y = 0; y < h; y++) {
 	QRgb *scanLine = reinterpret_cast<QRgb *>( image.scanLine(y) );
 	for (int x = 0; x < w; x++) {
@@ -820,10 +834,10 @@ ImlibImage * ImageCache::loadImageWithQt( const QString& fileName ) const
 	    *(newData++) = qBlue(pixel);
 	}
     }
-    
+
     ImlibImage *im = Imlib_create_image_from_data( myId, newImageData, NULL,
                                                    image.width(), image.height() );
-		    
+		
     delete[] newImageData;
 
     return im;
