@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef KUICKDATA_H
@@ -68,7 +68,7 @@ public:
     bool 	downScale        :1;
     bool 	upScale          :1;
     int 	maxUpScale;
-    uint 	maxWidth, maxHeight;
+    float 	maxZoomFactor;
     uint        maxCachedImages;
     Rotation 	rotation;
 
